@@ -1,10 +1,10 @@
 #' Relative Frequency of Citation (RFC)
 #'
-#' Allows users to calculate the relative frequency of citation (RFC) per species published by Pardo-de-Santayana (2003).
+#' Calculates the relative frequency of citation (RFC) per species published by Pardo-de-Santayana (2003).
 #' @source Tardio, J., and M. Pardo-de-Santayana, 2008. Cultural Importance Indices: A Comparative Analysis Based on the Useful Wild Plants of Southern Cantabria (Northern Spain) 1. Economic Botany, 62(1), 24-39. <https://doi.org/10.1007/s12231-007-9004-5>
 #' @param data is an ethnobotany data set with column 1 'informant' and 2 'sp_name' as row identifiers of informants and of species names respectively.
 #' The rest of the columns are the identified ethnobotany use categories. The data should be populated with counts of uses per person (should be 0 or 1 values).
-#' @keywords quantitative ethnobotany, number of uses
+#' @keywords quantitative ethnobotany relative frequency citation
 #'
 #' @importFrom magrittr %>%
 #' @importFrom dplyr filter summarize select left_join group_by
@@ -63,6 +63,6 @@ RFCs <- function(data) {
       dplyr::arrange(-RFCs) %>%
       dplyr::mutate(RFCs = round(RFCs, 3))
     
-    print(as.data.frame(RFCs))
+    as.data.frame(RFCs)
     }
 
