@@ -1,10 +1,10 @@
-#' #Relative Importance Index (RI)
+#' Relative Importance index (RI)
 #'
-#' This function allows you to calculate the relative importance index (RI) per species, published by Pardo-de-Santayana (2003).
+#' Calculates the relative importance index (RI) per species, published by Pardo-de-Santayana (2003).
 #' @source Tardio, J., and M. Pardo-de-Santayana, 2008. Cultural Importance Indices: A Comparative Analysis Based on the Useful Wild Plants of Southern Cantabria (Northern Spain) 1. Economic Botany, 62(1), 24-39. <https://doi.org/10.1007/s12231-007-9004-5>
 #' @param data is an ethnobotany data set with column 1 'informant' and 2 'sp_name' as row identifiers of informants and of species names respectively.
 #' The rest of the columns are the identified ethnobotany use categories. The data should be populated with counts of uses per person (should be 0 or 1 values).
-#' @keywords quantitative ethnobotany, relative importance
+#' @keywords quantitative ethnobotany relative importance
 #'
 #' @importFrom magrittr %>%
 #' @importFrom stats aggregate
@@ -92,5 +92,5 @@ RIs <- function(data) {
       dplyr::select(sp_name, RIs) %>%
       dplyr::mutate(RIs = round(RIs, 3))
 
-    print(as.data.frame(RIs))
+    as.data.frame(RIs)
 }
