@@ -1,9 +1,10 @@
 #' Sum of all Use Reports (UR) for all species
 #'
-#' Allows users to calculate the sum of all ethnobotany use reports (UR) for all species, a common metric for ethnobotany studies.
+#' Calculates the sum of all ethnobotany use reports (UR) for all species, a common metric for ethnobotany studies.
+#' @source Prance, G. T., W. Baleé, B. M. Boom, and R. L. Carneiro. “Quantitative Ethnobotany and the Case for Conservation in Amazonia.” Conservation Biology 1, no. 4 (1987): 296–310.
 #' @param data is an ethnobotany data set with column 1 'informant' and 2 'sp_name' as row identifiers of informants and of species names respectively.
 #' The rest of the columns are the identified ethnobotany use categories. The data should be populated with counts of uses per person (should be 0 or 1 values).
-#' @keywords ethnobotany, use report, quantitative ethnobotany
+#' @keywords ethnobotany use report quantitative ethnobotany
 #'
 #' @importFrom dplyr select
 #' @importFrom assertthat validate_that
@@ -47,6 +48,5 @@ URsum <- function(data) {
   
   URsum <-  sum(dplyr::select(data, -informant, -sp_name))
   
-  print("Sum of all Use Reports (UR) for all species in the data set")
-  print(URsum)
+  URsum
 }
